Converting skins to views:
==========================

[x] ISiteRoot @@search_form.html:
---------------------------------
- [x] search_form.py -> search.Search
- [x] search_form_template.pt -> search.pt

[x] ISiteRoot @@search.html:
----------------------------
- [x] search.py -> search.SearchView
- [x] search_results_template.pt -> search_results.pt
